@@ -45,6 +45,16 @@ def do_uuid4():
     return uuid4()
 
 
+@register.filter
+def fieldset(obj, title, fields, actions=None, lookups=None):
+    return mark_safe('{}|{}|{}|{}<br>'.format(title, fields, actions, lookups))
+
+
+@register.filter
+def actions(obj, action_list):
+    return mark_safe('{}<br>'.format(action_list))
+
+
 @register.filter
 def full_date_format(value):
     locale.setlocale(locale.LC_ALL, "pt_BR")
