@@ -269,6 +269,13 @@ class CardPanel(Component):
                             if count:
                                 url = '/list/{}/{}/{}/'.format(app_label, model_name, attr_name)
                                 self.add(icon, title, count, url, '', None, item['verbose_name'])
+        for item in CACHE['SUBSET_WIDGETS']:
+            if item.get('shortcut'):
+                if permissions.check_group_or_permission(request, item['can_view']):
+                    icon = item.get('icon', get_metadata(model, 'icon'))
+                    self.add(
+                        item['icon'], item['verbose_name'], None, item['url'], item['can_view'], ''
+                    )
 
     def add(self, icon, title, count=None, url=None, css='', perm_or_group=None, description=''):
         if permissions.check_group_or_permission(self.request, perm_or_group):
